@@ -1,13 +1,17 @@
+from typing import Any, Type, Callable
+
+from .annotations import Decorator, F
+
 __all__ = ['implements']
 
 
-def implements(interface_class):
+def implements(interface_class: Type[Any]) -> Callable[[F], F]:
 
     if not isinstance(interface_class, type):
         raise TypeError(
             f"interface class {interface_class} is not a type")
 
-    def decorated_method(method):
+    def decorated_method(method: F) -> F:
         if method.__name__ not in vars(interface_class):
             raise TypeError(
                 f"{method.__name__} not found in interface class "
@@ -18,7 +22,7 @@ def implements(interface_class):
             raise TypeError(
                 f"{method.__name__} in {interface_class.__name__} "
                 "is not abstract")
-        method.__implemented_from__ = interface_class
+        method.__implemented_from__ = interface_class  # type: ignore
         return method
 
     return decorated_method
