@@ -6,18 +6,18 @@ from ipromise import AbstractBaseClass, implements
 class HasAbstractMethod(AbstractBaseClass):
 
     @abstractmethod
-    def f(self):
+    def f(self) -> int:
         raise NotImplementedError
 
 
 class ImplementsAbstractMethod(HasAbstractMethod):
 
     @implements(HasAbstractMethod)
-    def f(self):
+    def f(self) -> int:
         return 0
 
 
 class HasRegularMethod(AbstractBaseClass):
 
-    def f(self):
+    def f(self) -> int:
         return 1
